@@ -3,15 +3,9 @@ from typing import Dict, List, Optional
 from ply.lex import LexToken
 
 from simple_ddl_parser import tokens as tok
-from simple_ddl_parser.dialects.bigquery import BigQuery
-from simple_ddl_parser.dialects.hql import HQL
-from simple_ddl_parser.dialects.mssql import MSSQL
-from simple_ddl_parser.dialects.mysql import MySQL
-from simple_ddl_parser.dialects.oracle import Oracle
-from simple_ddl_parser.dialects.redshift import Redshift
-from simple_ddl_parser.dialects.snowflake import Snowflake
-from simple_ddl_parser.dialects.spark_sql import SparkSQL
-from simple_ddl_parser.dialects.sql import BaseSQL
+from simple_ddl_parser.dialects import (HQL, MSSQL, PSQL, BaseSQL, BigQuery,
+                                        IBMDb2, MySQL, Oracle, Redshift,
+                                        Snowflake, SparkSQL)
 from simple_ddl_parser.parser import Parser
 
 
@@ -19,8 +13,14 @@ class DDLParserError(Exception):
     pass
 
 
+class Dialects(
+    SparkSQL, Snowflake, BaseSQL, HQL, MySQL, MSSQL, Oracle, Redshift, BigQuery, IBMDb2, PSQL
+):
+    pass
+
+
 class DDLParser(
-    Parser, SparkSQL, Snowflake, BaseSQL, HQL, MySQL, MSSQL, Oracle, Redshift, BigQuery
+    Parser, Dialects
 ):
 
     tokens = tok.tokens
@@ -221,7 +221,7 @@ class DDLParser(
             for num, symbol in enumerate(delimeters_to_start):
                 if p[0].startswith(symbol) and p[0].endswith(delimeters_to_end[num]):
                     p[0] = p[0][1:-1]
-    
+
     def p_id_or_string(self, p):
         """id_or_string : id
         | STRING"""
